@@ -232,9 +232,17 @@ def deepcopy(file_list, folder, replace = None):
 def stats(file_list, title = ""):
     file_list = FileList.check(file_list)
 
+    if not title:
+        title = "Stats on files"
+
+    console.header(" - %s :" % title)
+
+    if len(file_list) == 0:
+        console.info(  "   No files ")
+        return False
+
     size = __exec("du -k  %s | cut  -f1 |(tr '\n' '+'; echo 0) | bc" % ' '.join(file_list))
     
-
     try:
         size = int(size)
     except Exception:
@@ -249,10 +257,7 @@ def stats(file_list, title = ""):
     else:
         lines = 0
     
-    if not title:
-        title = "Stats on files"
-
-    console.header(" - %s :" % title)
+    
     console.info(  "   ~ Files : %s" % len(file_list))
     console.info(  "   ~ Lines : %s  (%s per file)" % (lines, (lines / len(file_list))))
     console.info(  "   ~ Size : %s (%s per file)" % (hsizeof(size), hsizeof((size / len(file_list)))))
